@@ -237,10 +237,10 @@ out:
 /*
  * Remember loops to warn only once
  */
-static inline boolean remembernode (handle_t *restrict const peg) attribute((always_inline,nonnull(1)));
-static inline boolean remembernode (handle_t *restrict const peg)
+static inline bool remembernode (handle_t *restrict const peg) attribute((always_inline,nonnull(1)));
+static inline bool remembernode (handle_t *restrict const peg)
 {
-    register boolean ret = true;
+    register bool ret = true;
 
     if (peg->flags & DIR_LOOP)
 	goto out;
@@ -330,7 +330,7 @@ static void __follow (dir_t *restrict dir, dir_t *restrict skip, const int level
 
     for (tmp = dir; tmp; tmp = getnextlink(l_list)) {
 	const typeof(attof(tmp)->flags) sflags = attof(tmp)->flags;
-	register boolean recursion = true;
+	register bool recursion = true;
 	handle_t * ptmp = (mode == 'K') ? &tmp->stopp : &tmp->start;
 	uchar  * order = &ptmp->deep;
 	list_t * dent;
@@ -567,7 +567,7 @@ void lsort(const char type)
 		    if (dir->stopp.deep == order) {
 			service_t *const orig = getorig(rev->serv);
 			list_t * chk;
-			boolean found = false;
+			bool found = false;
 
 			list_for_each_prev(chk, &sort) {    /* check if service was already resorted */
 			    req_t * this = getreq(chk);
@@ -622,7 +622,7 @@ void lsort(const char type)
 		    if (dir->start.deep == order) {
 			service_t * orig = getorig(req->serv);
 			list_t * chk;
-			boolean found = false;
+			bool found = false;
 
 			list_for_each_prev(chk, &sort) {    /* check if service was already resorted */
 			    req_t * this = getreq(chk);
@@ -734,7 +734,7 @@ void nickservice(service_t *restrict orig, service_t *restrict nick)
 
     list_for_each_safe(dent, safe, &nick->sort.req) {
 	req_t * this = getreq(dent);
-	boolean ok = true;
+	bool ok = true;
 	list_t * req;
 	list_for_each(req, &orig->sort.req) {
 	    if (!strcmp(this->serv->name,getreq(req)->serv->name)) {
@@ -751,7 +751,7 @@ void nickservice(service_t *restrict orig, service_t *restrict nick)
 
     list_for_each_safe(dent, safe, &nick->sort.rev) {
 	req_t * this = getreq(dent);
-	boolean ok = true;
+	bool ok = true;
 	list_t * rev;
 	list_for_each(rev, &orig->sort.rev) {
 	    if (!strcmp(this->serv->name,getreq(rev)->serv->name)) {
@@ -851,7 +851,7 @@ void clear_all(void)
 
 	    list_for_each_safe(dent, safe, &orv->sort.req) {
 		req_t * this = getreq(dent);
-		boolean ok = true;
+		bool ok = true;
 		list_t * req;
 		list_for_each(req, &srv->sort.req) {
 		    if (!strcmp(this->serv->name,getreq(req)->serv->name)) {
@@ -873,7 +873,7 @@ void clear_all(void)
 
 	    list_for_each_safe(dent, safe, &orv->sort.rev) {
 		req_t * this = getreq(dent);
-		boolean ok = true;
+		bool ok = true;
 		list_t * rev;
 		list_for_each(rev, &srv->sort.rev) {
 		   if (!strcmp(this->serv->name,getreq(rev)->serv->name)) {
@@ -926,7 +926,7 @@ void follow_all(void)
     }
 }
 
-boolean is_loop_detected(void)
+bool is_loop_detected(void)
 {
     list_t *tmp;
     list_for_each(tmp, d_start) {
@@ -1020,10 +1020,10 @@ void show_all()
 /*
  * Used within loops to get scripts not included in this runlevel
  */
-boolean notincluded(const char *restrict const script, const char mode, const int runlevel)
+bool notincluded(const char *restrict const script, const char mode, const int runlevel)
 {
     list_t *tmp;
-    boolean ret = false;
+    bool ret = false;
     const ushort lvl = map_runlevel_to_lvl (runlevel);
 
     list_for_each_prev(tmp, d_start) {
@@ -1128,7 +1128,7 @@ void runlevels(service_t *restrict serv, const char mode, const char *restrict l
  * Reorder all services starting with a service
  * being in same runlevels.
  */
-void setorder(const char *restrict script, const char mode, const int order, const boolean recursive)
+void setorder(const char *restrict script, const char mode, const int order, const bool recursive)
 {
     dir_t * dir = findscript(script);
     handle_t * peg;
@@ -1194,11 +1194,11 @@ int getorder(const char *restrict script, const char mode)
  * One script and several provided facilities leads
  * to the same order for those facilities.
  */
-boolean makeprov(service_t *restrict serv, const char *restrict script)
+bool makeprov(service_t *restrict serv, const char *restrict script)
 {
     dir_t *restrict alias = findscript(script);
     dir_t *restrict dir   = (dir_t *restrict)serv->dir;
-    boolean ret = true;
+    bool ret = true;
 
     if (!dir->script) {
 	list_t * ptr;
