@@ -20,11 +20,11 @@
  *
  */
 
+#include <stdbool.h>
 #include <stddef.h>
 #include <sys/types.h>
 #include "config.h"
 
-typedef enum _boolean {false, true} boolean;
 typedef unsigned char uchar;
 #ifndef __USE_MISC
 typedef unsigned short ushort;
@@ -191,8 +191,8 @@ static inline void join(list_t *restrict list, list_t *restrict head)
     }
 }
 
-static inline boolean list_empty(const list_t *restrict const head) attribute((always_inline,nonnull(1)));
-static inline boolean list_empty(const list_t *restrict const head)
+static inline bool list_empty(const list_t *restrict const head) attribute((always_inline,nonnull(1)));
+static inline bool list_empty(const list_t *restrict const head)
 {
      return head->next == head;
 }
@@ -308,14 +308,14 @@ extern void follow_all(void);
 extern void show_all(void);
 extern void requires(service_t *restrict this, service_t *restrict dep, const char mode) attribute((nonnull(1,2)));
 extern void runlevels(service_t *restrict serv, const char mode, const char *restrict lvl) attribute((nonnull(1,3)));
-extern boolean makeprov(service_t *restrict serv, const char *restrict script) attribute((nonnull(1,2)));
-extern void setorder(const char *restrict script, const char mode, const int order, const boolean recursive) attribute((nonnull(1)));
+extern bool makeprov(service_t *restrict serv, const char *restrict script) attribute((nonnull(1,2)));
+extern void setorder(const char *restrict script, const char mode, const int order, const bool recursive) attribute((nonnull(1)));
 extern int getorder(const char *restrict script, const char mode) attribute((nonnull(1)));
-extern boolean notincluded(const char *restrict const script, const char mode, const int runlevel) attribute((nonnull(1)));
+extern bool notincluded(const char *restrict const script, const char mode, const int runlevel) attribute((nonnull(1)));
 extern const char * getscript(const char *restrict prov) attribute((nonnull(1)));
 extern const char * getprovides(const char *restrict script) attribute((nonnull(1)));
 extern service_t * listscripts(const char **restrict script, const char mode, const ushort lvl);
-extern boolean is_loop_detected(void);
+extern bool is_loop_detected(void);
 extern service_t * addservice(const char *restrict const serv) attribute((malloc,nonnull(1)));
 extern service_t * findservice(const char *restrict const name);
 extern service_t * getorig(service_t *restrict serv) attribute((const,nonnull(1)));
